from django.test import TestCase
from django.urls import reverse
from django.contrib.auth.models import Group
from guardian.shortcuts import assign_perm
from . import models

class KeyDecodeerror(TestCase):
    """Check pages load even if the key cannot be decoded"""

    def setUp(self):
        self.toykey = models.SSHPublicKey.objects.create(
            hostname="example.com",
            keytype="",
            key="no such thing",
        )
        any_user = Group.objects.get(name="any-user")
        assign_perm('view_sshpublickey', any_user, self.toykey)

    def test_detail(self):
        """Check that the detail page loads successfully"""
        response = self.client.get(
            reverse('ssh-detail', args=[self.toykey.pk])
        )
        self.assertEqual(response.status_code, 200)

    def test_list(self):
        """Check that the list page loads successfully"""
        response = self.client.get(
            reverse('ssh-list')
        )
        self.assertEqual(response.status_code, 200)
